@@ -167,43 +167,77 @@ repair_table_names_for_db <- function(table_names, temporary, con) {
   quote_ids(names, con)
 }
 
-get_src_tbl_names <- function(src, schema = NULL) {
-  con <- src$con
-
-  if (is_null(schema)) {
-    if (!is_mssql(src) && !is_postgres(src)) {
-      # `src_tbls()` returns system tables and tables in other schemas than default schema only for MSSQL
-      return(src_tbls(src))
-    } else if (is_mssql(src)) {
-      # MSSQL
-      schema <- "dbo"
-    } else {
-      # Postgres
-      schema <- "public"
-    }
-  } else if (!is_mssql(con) && !is_postgres(con)) {
-    warn("Argument 'schema' ignored: currently only supports MSSQL and Postgres")
+get_src_tbl_names <- function(src, schema = NULL, dbname = NULL) {
+  if (!is_mssql(src) && !is_postgres(src)) {
+    warn_if_not_null(schema)
+    warn_if_not_null(dbname, only_on = "MSSQL")
     return(src_tbls(src))
   }
 
-  # src is now either Postgres or MSSQL, schema is not `NULL`
+  con <- src$con
+
   if (is_mssql(src)) {
     # MSSQL
-    names_table <- DBI::dbGetQuery(
-      con,
-      "SELECT name AS table_name, schema_name(schema_id) AS schema_name FROM sys.tables"
-    )
-  } else {
+    schema <- schema_mssql(con, schema)
+    dbname_sql <- dbname_mssql(con, dbname)
+    names_table <- get_names_table_mssql(con, dbname_sql)
+    dbname <- names(dbname_sql)
+  } else if (is_postgres(src)) {
     # Postgres
-    names_table <- DBI::dbGetQuery(
-      con,
-      "SELECT table_schema as schema_name, table_name as table_name from information_schema.tables"
-    )
+    schema <- schema_postgres(con, schema)
+    dbname <- warn_if_not_null(dbname, only_on = "MSSQL")
+    names_table <- get_names_table_postgres(con)
   }
-  tables_in_schema <- names_table %>%
+  check_param_class(schema, "character")
+  check_param_length(schema)
+  names_table %>%
     filter(schema_name == !!schema) %>%
-  # create remote names for the tables in the given schema (name is table_name; cannot be duplicated within a single schema)
-    mutate(remote_name = schema_if(schema_name, table_name, con)) %>%
+    # create remote names for the tables in the given schema (name is table_name; cannot be duplicated within a single schema)
+    mutate(remote_name = schema_if(schema_name, table_name, con, dbname)) %>%
     select(-schema_name) %>%
     deframe()
 }
+
+# `schema_*()` : default schema if NULL, otherwise unchanged
+schema_mssql <- function(con, schema) {
+  if (is_null(schema)) {
+    schema <- "dbo"
+  }
+  schema
+}
+
+schema_postgres <- function(con, schema) {
+  if (is_null(schema)) {
+    schema <- "public"
+  }
+  schema
+}
+
+dbname_mssql <- function(con, dbname) {
+  if (is_null(dbname)) {
+    dbname <- ""
+    dbname_sql <- ""
+  } else {
+    check_param_class(dbname, "character")
+    dbname_sql <- paste0(DBI::dbQuoteIdentifier(con, dbname), ".")
+  }
+  set_names(dbname_sql, dbname)
+}
+
+
+get_names_table_mssql <- function(con, dbname_sql) {
+  DBI::dbGetQuery(
+    con,
+    glue::glue("SELECT tabs.name AS table_name, schemas.name AS schema_name
+      FROM {dbname_sql}sys.tables tabs
+      INNER JOIN {dbname_sql}sys.schemas schemas ON
+      tabs.schema_id = schemas.schema_id")
+  )
+}
+
+get_names_table_postgres <- function(con) {
+  DBI::dbGetQuery(
+    con,
+    "SELECT table_schema as schema_name, table_name as table_name from information_schema.tables"
+  )
+}
