@@ -540,3 +540,45 @@ error_txt_temp_table_requested <- function(table_names, tbls_in_dm) {
     "{commas(tick(temp_tables))}."
   )
 }
+
+abort_parameter_not_correct_class <- function(parameter, correct_class, class) {
+  abort(error_txt_parameter_not_correct_class(
+    parameter,
+    correct_class,
+    class),
+    .subclass = dm_error_full("parameter_not_correct_class")
+  )
+}
+
+error_txt_parameter_not_correct_class <- function(parameter, correct_class, class) {
+  glue(
+    "Parameter {tick(parameter)} needs to be of class {tick(correct_class)} but is of class {format_classes(class)}."
+  )
+}
+
+abort_parameter_not_correct_length <- function(parameter, correct_length, parameter_value) {
+  abort(error_txt_parameter_not_correct_length(
+    parameter,
+    correct_length,
+    parameter_value),
+    .subclass = dm_error_full("parameter_not_correct_length")
+  )
+}
+
+error_txt_parameter_not_correct_length <- function(parameter, correct_length, parameter_value) {
+  glue(
+    "Parameter {tick(parameter)} needs to be of length {tick(correct_length)} but is ",
+    "of length {as.character(length(parameter_value))} ({commas(tick(parameter_value))})."
+  )
+}
+
+warn_if_not_null <- function(arg, arg_name = deparse(substitute(arg)), only_on = c("MSSQL", "Postgres")) {
+  if (!is.null(arg)) {
+    dm_warn(
+      glue::glue(
+        "Argument {tick(arg_name)} ignored: currently only supported for {paste0(only_on, collapse = ' and ')}."
+      ), class = "non_null_param"
+    )
+  }
+  NULL
+}
