@@ -125,6 +125,30 @@ check_one_zoom <- function(def, zoomed) {
   }
 }
 
+
+# more general 'check'-type functions -------------------------------------
+
+
+check_param_class <- function(param_value, correct_class, param_name = deparse(substitute(param_value))) {
+  if (!inherits(param_value, correct_class)) {
+    abort_parameter_not_correct_class(
+      parameter = param_name,
+      correct_class = correct_class,
+      class = class(param_value)
+    )
+  }
+}
+
+check_param_length <- function(param_value, correct_length = 1, param_name = deparse(substitute(param_value))) {
+  if (length(param_value) != correct_length) {
+    abort_parameter_not_correct_length(
+      parameter = param_name,
+      correct_length = correct_length,
+      param_value
+    )
+  }
+}
+
 # general error: table not part of `dm` -----------------------------------
 
 abort_table_missing <- function(arg_name) {
